@@ -15,7 +15,7 @@ class GenerationTrainArguments:
         metadata={"help": "The name of the downstream data."}
     )
     downstream_corpus_name: str = field(
-        default=None,
+        default="nsmc",
         metadata={"help": "The name of the downstream data."}
     )
     downstream_corpus_root_dir: str = field(
@@ -23,7 +23,7 @@ class GenerationTrainArguments:
         metadata={"help": "The root directory of the downstream data."}
     )
     downstream_model_dir: str = field(
-        default=None,
+        default="/gdrive/My Drive/nlpbook/checkpoint-generation",
         metadata={"help": "The output model dir."}
     )
     max_seq_length: int = field(
@@ -61,16 +61,8 @@ class GenerationTrainArguments:
         default=5e-5,
         metadata={"help": "learning rate"}
     )
-    optimizer: str = field(
-        default="AdamW",
-        metadata={"help": "optimizer"}
-    )
-    lr_scheduler: str = field(
-        default="exp",
-        metadata={"help": "ExponentialLR or CosineAnnealingWarmRestarts"}
-    )
     epochs: int = field(
-        default=20,
+        default=3,
         metadata={"help": "max epochs"}
     )
     batch_size: int = field(
@@ -109,10 +101,10 @@ class GenerationDeployArguments:
             if len(ckpt_file_names) == 0:
                 raise Exception(f"downstream_model_dir \"{downstream_model_dir}\" is not valid")
             selected_fname = ckpt_file_names[-1]
-            min_val_loss = os.path.split(selected_fname)[-1].replace(".ckpt", "").split("=")[-1]
+            min_val_loss = os.path.split(selected_fname)[-1].replace(".ckpt", "").split("=")[-1].split("-")[0]
             try:
                 for ckpt_file_name in ckpt_file_names:
-                    val_loss = os.path.split(ckpt_file_name)[-1].replace(".ckpt", "").split("=")[-1]
+                    val_loss = os.path.split(ckpt_file_name)[-1].replace(".ckpt", "").split("=")[-1].split("-")[0]
                     if float(val_loss) < float(min_val_loss):
                         selected_fname = ckpt_file_name
                         min_val_loss = val_loss
